@@ -1,27 +1,25 @@
-/* $Xorg: FSlibInt.c,v 1.5 2001/02/09 02:03:25 xorgcvs Exp $ */
-
 /*
  * Copyright 1990 Network Computing Devices;
  * Portions Copyright 1987 by Digital Equipment Corporation
  *
- * Permission to use, copy, modify, distribute, and sell this software 
- * and its documentation for any purpose is hereby granted without fee, 
- * provided that the above copyright notice appear in all copies and 
- * that both that copyright notice and this permission notice appear 
- * in supporting documentation, and that the names of Network Computing 
- * Devices or Digital not be used in advertising or publicity pertaining 
- * to distribution of the software without specific, written prior 
- * permission. Network Computing Devices or Digital make no representations 
- * about the suitability of this software for any purpose.  It is provided 
+ * Permission to use, copy, modify, distribute, and sell this software
+ * and its documentation for any purpose is hereby granted without fee,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear
+ * in supporting documentation, and that the names of Network Computing
+ * Devices or Digital not be used in advertising or publicity pertaining
+ * to distribution of the software without specific, written prior
+ * permission. Network Computing Devices or Digital make no representations
+ * about the suitability of this software for any purpose.  It is provided
  * "as is" without express or implied warranty.
  *
  * NETWORK COMPUTING DEVICES AND  DIGITAL DISCLAIM ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF 
+ * REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
  * MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL NETWORK COMPUTING DEVICES
- * OR DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES 
- * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, 
- * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, 
- * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS 
+ * OR DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
  * SOFTWARE.
  */
 
@@ -50,7 +48,6 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/lib/FS/FSlibInt.c,v 3.10tsi Exp $ */
 
 /*
  *	FSlibInt.c - Internal support routines for the C subroutine
@@ -64,7 +61,7 @@ in this Software without prior written authorization from The Open Group.
 #include <X11/Xos.h>
 
 static void _EatData32 ( FSServer *svr, unsigned long n );
-static char * _SysErrorMsg ( int n );
+static const char * _SysErrorMsg ( int n );
 
 /* check for both EAGAIN and EWOULDBLOCK, because some supposedly POSIX
  * systems are broken and return EWOULDBLOCK when they should return EAGAIN
@@ -130,9 +127,8 @@ static fsReq _dummy_request = {
  * action is taken.  This routine correctly handles incremental writes.
  * This routine may have to be reworked if int < long.
  */
-void 
-_FSFlush(svr)
-    register FSServer *svr;
+void
+_FSFlush(register FSServer *svr)
 {
     register long size,
                 todo;
@@ -177,9 +173,9 @@ _FSFlush(svr)
 }
 
 int
-_FSEventsQueued(svr, mode)
-    register FSServer *svr;
-    int         mode;
+_FSEventsQueued(
+    register FSServer	*svr,
+    int			 mode)
 {
     register BytesReadable_t len;
     BytesReadable_t pend;
@@ -215,9 +211,8 @@ _FSEventsQueued(svr, mode)
 /* _FSReadEvents - Flush the output queue,
  * then read as many events as possible (but at least 1) and enqueue them
  */
-void 
-_FSReadEvents(svr)
-    register FSServer *svr;
+void
+_FSReadEvents(register FSServer *svr)
 {
     char        buf[BUFSIZE];
     BytesReadable_t pend_not_register;	/* because can't "&" a register
@@ -273,11 +268,11 @@ _FSReadEvents(svr)
  * _FSRead - Read bytes from the socket taking into account incomplete
  * reads.  This routine may have to be reworked if int < long.
  */
-void 
-_FSRead(svr, data, size)
-    register FSServer *svr;
-    register char *data;
-    register long size;
+void
+_FSRead(
+    register FSServer	*svr,
+    register char	*data,
+    register long	 size)
 {
     register long bytes_read;
 #if defined(SVR4) && defined(i386)
@@ -348,12 +343,12 @@ _FSRead(svr, data, size)
  *            into a long (64 bits on a CRAY computer).
  *
  */
-static void 
-_doFSRead32(svr, data, size, packbuffer)
-    register FSServer *svr;
-    register long *data;
-    register long size;
-    register char *packbuffer;
+static void
+_doFSRead32(
+    register FSServer	*svr,
+    register long	*data,
+    register long	 size,
+    register char	*packbuffer)
 {
     long       *lpack,
                *lp;
@@ -381,10 +376,10 @@ _doFSRead32(svr, data, size, packbuffer)
 }
 
 void
-_FSRead32(svr, data, len)
-    FSServer   *svr;
-    long       *data;
-    long        len;
+_FSRead32(
+    FSServer	*svr,
+    long	*data,
+    long	 len)
 {
     char        packbuffer[PACKBUFFERSIZE];
     unsigned    nwords = (PACKBUFFERSIZE >> 2);	/* bytes to CARD32 */
@@ -402,12 +397,12 @@ _FSRead32(svr, data, len)
  *            into a long (64 bits on a CRAY computer).
  *
  */
-static void 
-_doFSRead16(svr, data, size, packbuffer)
-    register FSServer *svr;
-    register short *data;
-    register long size;
-    char       *packbuffer;
+static void
+_doFSRead16(
+    register FSServer	*svr,
+    register short	*data,
+    register long	 size,
+    char		*packbuffer)
 {
     long       *lpack,
                *lp;
@@ -434,11 +429,11 @@ _doFSRead16(svr, data, size, packbuffer)
     }
 }
 
-void 
-_FSRead16(svr, data, len)
-    FSServer   *svr;
-    short      *data;
-    long        len;
+void
+_FSRead16(
+    FSServer	*svr,
+    short	*data,
+    long	 len)
 {
     char        packbuffer[PACKBUFFERSIZE];
     unsigned    nwords = (PACKBUFFERSIZE >> 1);	/* bytes to CARD16 */
@@ -449,11 +444,11 @@ _FSRead16(svr, data, len)
     _doFSRead16(svr, data, len, packbuffer);
 }
 
-void 
-_FSRead16Pad(svr, data, size)
-    FSServer   *svr;
-    short      *data;
-    long        size;
+void
+_FSRead16Pad(
+    FSServer	*svr,
+    short	*data,
+    long	 size)
 {
     int         slop = (size & 3);
     short       slopbuf[3];
@@ -472,11 +467,11 @@ _FSRead16Pad(svr, data, size)
  * reads.  If the number of bytes is not 0 mod 32, read additional pad
  * bytes. This routine may have to be reworked if int < long.
  */
-void 
-_FSReadPad(svr, data, size)
-    register FSServer *svr;
-    register char *data;
-    register long size;
+void
+_FSReadPad(
+    register FSServer	*svr,
+    register char	*data,
+    register long	 size)
 {
     register long bytes_read;
     struct iovec iov[2];
@@ -538,11 +533,11 @@ _FSReadPad(svr, data, size)
  * transmission is used, if size is not 0 mod 4, extra bytes are transmitted.
  * This routine may have to be reworked if int < long;
  */
-void 
-_FSSend(svr, data, size)
-    register FSServer *svr;
-    char       *data;
-    register long size;
+void
+_FSSend(
+    register FSServer	*svr,
+    const char		*data,
+    register long	 size)
 {
     struct iovec iov[3];
     static char pad[3] = {0, 0, 0};
@@ -555,10 +550,10 @@ _FSSend(svr, data, size)
 
     /*
      * There are 3 pieces that may need to be written out:
-     * 
+     *
      * o  whatever is in the display buffer o  the data passed in by the user o
      * any padding needed to 32bit align the whole mess
-     * 
+     *
      * This loop looks at all 3 pieces each time through.  It uses skip to figure
      * out whether or not a given piece is needed.
      */
@@ -572,12 +567,12 @@ _FSSend(svr, data, size)
 	 * You could be very general here and have "in" and "out" iovecs and
 	 * write a loop without using a macro, but what the heck.  This
 	 * translates to:
-	 * 
+	 *
 	 * how much of this piece is new? if more new then we are trying this
 	 * time, clamp if nothing new then bump down amount already written,
 	 * for next piece else put new stuff in iovec, will need all of next
 	 * piece
-	 * 
+	 *
 	 * Note that todo had better be at least 1 or else we'll end up writing 0
 	 * iovecs.
 	 */
@@ -596,7 +591,7 @@ _FSSend(svr, data, size)
 	    }
 
 	InsertIOV(svr->buffer, svrbufsize)
-	InsertIOV(data, size)
+	InsertIOV((char *)data, size)
 	InsertIOV(pad, padsize)
 
 	ESET(0);
@@ -634,8 +629,7 @@ _FSSend(svr, data, size)
  * follow the rules.
  */
 FSID
-_FSAllocID(svr)
-    register FSServer *svr;
+_FSAllocID(register FSServer *svr)
 {
     return (svr->resource_base + (svr->resource_id++ << svr->resource_shift));
 }
@@ -652,9 +646,9 @@ _FSAllocID(svr)
  */
 
 unsigned long
-_FSSetLastRequestRead(svr, rep)
-    register FSServer *svr;
-    register fsGenericReply *rep;
+_FSSetLastRequestRead(
+    register FSServer		*svr,
+    register fsGenericReply	*rep)
 {
     register unsigned long newseq,
                 lastseq;
@@ -684,13 +678,13 @@ _FSSetLastRequestRead(svr, rep)
  * we may encounter.
  */
 Status
-_FSReply(svr, rep, extra, discard)
-    register FSServer *svr;
-    register fsReply *rep;
-    int         extra;		/* number of 32-bit words expected after the
-				 * reply */
-    Bool        discard;	/* should I discard data followind "extra"
-				 * words? */
+_FSReply(
+    register FSServer	*svr,
+    register fsReply	*rep,
+    int			 extra,	 /* number of 32-bit words expected after the
+				  * reply */
+    Bool		 discard)/* should I discard data followind "extra"
+				  * words? */
 {
     /*
      * Pull out the serial number now, so that (currently illegal) requests
@@ -754,7 +748,8 @@ _FSReply(svr, rep, extra, discard)
 		unsigned long serial;
 		long        err_data;
 
-		err = *(fsError *) rep;
+		/* copy in the part we already read off the wire */
+		memcpy(&err, rep, SIZEOF(fsReply));
 		/* read the rest of the error */
 		_FSRead(svr, (char *) &err + SIZEOF(fsReply),
 			(long) (SIZEOF(fsError) - SIZEOF(fsReply)));
@@ -808,9 +803,9 @@ _FSReply(svr, rep, extra, discard)
 /* Read and discard "n" 8-bit bytes of data */
 
 void
-_FSEatData(svr, n)
-    FSServer   *svr;
-    register unsigned long n;
+_FSEatData(
+    FSServer			*svr,
+    register unsigned long	 n)
 {
 #define SCRATCHSIZE 2048
     char        buf[SCRATCHSIZE];
@@ -828,9 +823,9 @@ _FSEatData(svr, n)
 /* Read and discard "n" 32-bit words. */
 
 static void
-_EatData32(svr, n)
-    FSServer   *svr;
-    unsigned long n;
+_EatData32(
+    FSServer		*svr,
+    unsigned long	 n)
 {
     _FSEatData(svr, n << 2);
 }
@@ -841,10 +836,10 @@ _EatData32(svr, n)
  * note that no squishing of move events in V11, since there
  * is pointer motion hints....
  */
-void 
-_FSEnq(svr, event)
-    register FSServer *svr;
-    register fsEvent *event;
+void
+_FSEnq(
+    register FSServer	*svr,
+    register fsEvent	*event)
 {
     register _FSQEvent *qelt;
 
@@ -852,8 +847,7 @@ _FSEnq(svr, event)
     if ((qelt = _FSqfree) != NULL) {
 	/* If _FSqfree is non-NULL do this, else malloc a new one. */
 	_FSqfree = qelt->next;
-    } else if ((qelt =
-	     (_FSQEvent *) FSmalloc((unsigned) sizeof(_FSQEvent))) == NULL) {
+    } else if ((qelt = FSmalloc(sizeof(_FSQEvent))) == NULL) {
 	/* Malloc call failed! */
 	ESET(ENOMEM);
 	(*_FSIOErrorFunction) (svr);
@@ -881,11 +875,11 @@ _FSEnq(svr, event)
 
 /*ARGSUSED*/
 Bool
-_FSUnknownWireEvent(svr, re, event)
-    register FSServer *svr;	/* pointer to display structure */
-    register FSEvent *re;	/* pointer to where event should be
+_FSUnknownWireEvent(
+    register FSServer	*svr,	/* pointer to display structure */
+    register FSEvent	*re,	/* pointer to where event should be
 				 * reformatted */
-    register fsEvent *event;	/* wire protocol event */
+    register fsEvent	*event)	/* wire protocol event */
 {
 
 #ifdef notdef
@@ -899,11 +893,11 @@ _FSUnknownWireEvent(svr, re, event)
 
 /*ARGSUSED*/
 Status
-_FSUnknownNativeEvent(svr, re, event)
-    register FSServer *svr;	/* pointer to display structure */
-    register FSEvent *re;	/* pointer to where event should be
+_FSUnknownNativeEvent(
+    register FSServer	*svr,	/* pointer to display structure */
+    register FSEvent	*re,	/* pointer to where event should be
 				 * reformatted */
-    register fsEvent *event;	/* wire protocol event */
+    register fsEvent	*event)	/* wire protocol event */
 {
 
 #ifdef notdef
@@ -919,11 +913,11 @@ _FSUnknownNativeEvent(svr, re, event)
  * reformat a wire event into an FSEvent structure of the right type.
  */
 Bool
-_FSWireToEvent(svr, re, event)
-    register FSServer *svr;	/* pointer to display structure */
-    register FSEvent *re;	/* pointer to where event should be
+_FSWireToEvent(
+    register FSServer	*svr,	/* pointer to display structure */
+    register FSEvent	*re,	/* pointer to where event should be
 				 * reformatted */
-    register fsEvent *event;	/* wire protocol event */
+    register fsEvent	*event)	/* wire protocol event */
 {
 
     re->type = event->type & 0x7f;
@@ -944,22 +938,25 @@ _FSWireToEvent(svr, re, event)
 }
 
 
-static char *
-_SysErrorMsg(n)
-    int         n;
+static const char *
+_SysErrorMsg(int n)
 {
     char       *s = strerror(n);
 
     return (s ? s : "no such error");
 }
 
+#ifdef __SUNPRO_C
+/* prevent "Function has no return statement" error for _FSDefaultIOError */
+#pragma does_not_return(exit)
+#endif
+
 /*
  * _FSDefaultIOError - Default fatal system error reporting routine.  Called
  * when an X internal system error is encountered.
  */
 int
-_FSDefaultIOError(svr)
-    FSServer   *svr;
+_FSDefaultIOError(FSServer *svr)
 {
     (void) fprintf(stderr,
 		   "FSIO:  fatal IO error %d (%s) on font server \"%s\"\r\n",
@@ -969,7 +966,7 @@ _FSDefaultIOError(svr)
 
 		   errno, _SysErrorMsg(errno),
 #endif
-		   FSServerString(svr));
+		   FSServerString(svr) ? FSServerString(svr) : "");
     (void) fprintf(stderr,
 		   "      after %lu requests (%lu known processed) with %d events remaining.\r\n",
 		   FSNextRequest(svr) - 1, FSLastKnownRequestProcessed(svr),
@@ -988,9 +985,9 @@ _FSDefaultIOError(svr)
  * FS_Error packet is encountered in the input stream.
  */
 int
-_FSError(svr, rep)
-    FSServer   *svr;
-    fsError    *rep;
+_FSError(
+    FSServer	*svr,
+    fsError	*rep)
 {
     FSErrorEvent event;
 
@@ -1012,28 +1009,33 @@ _FSError(svr, rep)
     /* NOTREACHED */
 }
 
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wformat-nonliteral" // We know better
+#endif
+
 int
-_FSPrintDefaultError(svr, event, fp)
-    FSServer   *svr;
-    FSErrorEvent *event;
-    FILE       *fp;
+_FSPrintDefaultError(
+    FSServer		*svr,
+    FSErrorEvent	*event,
+    FILE		*fp)
 {
     char        buffer[BUFSIZ];
     char        mesg[BUFSIZ];
     char        number[32];
-    char       *mtype = "FSlibMessage";
+    const char *mtype = "FSlibMessage";
     register _FSExtension *ext = (_FSExtension *) NULL;
 
     (void) FSGetErrorText(svr, event->error_code, buffer, BUFSIZ);
-    (void) FSGetErrorDatabaseText(svr, mtype, "FSError", "FS Error", mesg, 
+    (void) FSGetErrorDatabaseText(svr, mtype, "FSError", "FS Error", mesg,
 				  BUFSIZ);
     (void) fprintf(fp, "%s:  %s\n  ", mesg, buffer);
-    (void) FSGetErrorDatabaseText(svr, mtype, "MajorCode", 
+    (void) FSGetErrorDatabaseText(svr, mtype, "MajorCode",
 				  "Request Major code %d", mesg, BUFSIZ);
     (void) fprintf(fp, mesg, event->request_code);
     if (event->request_code < 128) {
-	sprintf(number, "%d", event->request_code);
-	(void) FSGetErrorDatabaseText(svr, "FSRequest", number, "", buffer, 
+	snprintf(number, sizeof(number), "%d", event->request_code);
+	(void) FSGetErrorDatabaseText(svr, "FSRequest", number, "", buffer,
 				      BUFSIZ);
     } else {
 	for (ext = svr->ext_procs;
@@ -1045,12 +1047,12 @@ _FSPrintDefaultError(svr, event, fp)
 	    buffer[0] = '\0';
     }
     (void) fprintf(fp, " (%s)\n  ", buffer);
-    (void) FSGetErrorDatabaseText(svr, mtype, "MinorCode", 
+    (void) FSGetErrorDatabaseText(svr, mtype, "MinorCode",
 				  "Request Minor code %d", mesg, BUFSIZ);
     (void) fprintf(fp, mesg, event->minor_code);
     if (ext) {
-	sprintf(mesg, "%s.%d", ext->name, event->minor_code);
-	(void) FSGetErrorDatabaseText(svr, "FSRequest", mesg, "", buffer, 
+	snprintf(mesg, sizeof(mesg), "%s.%d", ext->name, event->minor_code);
+	(void) FSGetErrorDatabaseText(svr, "FSRequest", mesg, "", buffer,
 				      BUFSIZ);
 	(void) fprintf(fp, " (%s)", buffer);
     }
@@ -1063,17 +1065,21 @@ _FSPrintDefaultError(svr, event, fp)
 				  mesg, BUFSIZ);
     (void) fprintf(fp, mesg, event->serial);
     fputs("\n  ", fp);
-    (void) FSGetErrorDatabaseText(svr, mtype, "CurrentSerial", 
+    (void) FSGetErrorDatabaseText(svr, mtype, "CurrentSerial",
 				  "Current Serial #%d", mesg, BUFSIZ);
     (void) fprintf(fp, mesg, svr->request);
     fputs("\n", fp);
     return 1;
 }
 
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
+
 int
-_FSDefaultError(svr, event)
-    FSServer   *svr;
-    FSErrorEvent *event;
+_FSDefaultError(
+    FSServer		*svr,
+    FSErrorEvent	*event)
 {
     if (_FSPrintDefaultError(svr, event, stderr) == 0)
 	return 0;
@@ -1091,43 +1097,41 @@ FSErrorHandler _FSErrorFunction = _FSDefaultError;
  * each time, unless the library needs a large scratch space.
  */
 char       *
-_FSAllocScratch(svr, nbytes)
-    register FSServer *svr;
-    unsigned long nbytes;
+_FSAllocScratch(
+    register FSServer	*svr,
+    unsigned long	 nbytes)
 {
     if (nbytes > svr->scratch_length) {
 	if (svr->scratch_buffer != NULL)
 	    FSfree(svr->scratch_buffer);
 	return (svr->scratch_length = nbytes,
-		svr->scratch_buffer = FSmalloc((unsigned) nbytes));
+		svr->scratch_buffer = FSmalloc(nbytes));
     }
     return (svr->scratch_buffer);
 }
 
-int 
-FSFree(data)
-    char       *data;
+int
+FSFree(char *data)
 {
     FSfree(data);
     return 1;
 }
 
 unsigned char *
-FSMalloc(size)
-    unsigned    size;
+FSMalloc(unsigned size)
 {
     return (unsigned char *) FSmalloc(size);
 }
 
 #ifdef DataRoutineIsProcedure
 void
-Data(svr, data, len)
-    FSServer   *svr;
-    char       *data;
-    long        len;
+Data(
+    FSServer	*svr,
+    char	*data,
+    long	 len)
 {
     if (svr->bufptr + (len) <= svr->bufmax) {
-	bcopy(data, svr->bufptr, (int) len);
+	memmove(svr->bufptr, data, len);
 	svr->bufptr += ((len) + 3) & ~3;
     } else {
 	_FSSend(svr, data, len);
@@ -1152,11 +1156,11 @@ Data(svr, data, len)
  */
 
 static void
-doData16(svr, data, len, packbuffer)
-    register FSServer *svr;
-    short      *data;
-    unsigned    len;
-    char       *packbuffer;
+doData16(
+    register FSServer	*svr,
+    short		 *data,
+    unsigned		 len,
+    char		*packbuffer)
 {
     long       *lp,
                *lpack;
@@ -1190,10 +1194,10 @@ doData16(svr, data, len, packbuffer)
 }
 
 void
-Data16(svr, data, len)
-    FSServer   *svr;
-    short      *data;
-    unsigned    len;
+Data16(
+    FSServer	*svr,
+    short	*data,
+    unsigned	 len)
 {
     char        packbuffer[PACKBUFFERSIZE];
     unsigned    nwords = (PACKBUFFERSIZE >> 1);	/* bytes to CARD16 */
@@ -1213,11 +1217,11 @@ Data16(svr, data, len)
  */
 
 static
-doData32(svr, data, len, packbuffer)
-    register FSServer *svr;
-    long       *data;
-    unsigned    len;
-    char       *packbuffer;
+doData32(
+    register FSServer	*svr,
+    long		*data,
+    unsigned		 len,
+    char		*packbuffer)
 {
     long       *lp,
                *lpack;
@@ -1251,10 +1255,10 @@ doData32(svr, data, len, packbuffer)
 }
 
 void
-Data32(svr, data, len)
-    FSServer   *svr;
-    short      *data;
-    unsigned    len;
+Data32(
+    FSServer	*svr,
+    short	*data,
+    unsigned	 len)
 {
     char        packbuffer[PACKBUFFERSIZE];
     unsigned    nwords = (PACKBUFFERSIZE >> 2);	/* bytes to CARD32 */
@@ -1275,7 +1279,7 @@ Data32(svr, data, len)
  */
 
 void
-_FSFreeQ()
+_FSFreeQ(void)
 {
     register _FSQEvent *qelt = _FSqfree;
 
@@ -1297,9 +1301,6 @@ _FSFreeQ()
 #ifdef hpux
 #define NEED_UTSNAME
 #endif
-#ifdef USG
-#define NEED_UTSNAME
-#endif
 #ifdef SVR4
 #ifndef _SEQUENT_
 #define NEED_UTSNAME
@@ -1315,9 +1316,9 @@ _FSFreeQ()
  * _FSGetHostname - similar to gethostname but allows special processing.
  */
 int
-_FSGetHostname(buf, maxlen)
-    char       *buf;
-    int         maxlen;
+_FSGetHostname(
+    char	*buf,
+    int		 maxlen)
 {
     int         len;
 
@@ -1347,8 +1348,7 @@ _FSGetHostname(buf, maxlen)
 /*
  * This is not always a macro.
  */
-_FSANYSET(src)
-    long	*src;
+_FSANYSET(long *src)
 {
     int i;
 
